######### F. prausnitzii OrthoMCL-based comparative genomics##########
######### A.N Shkoporov & C.B. Fitzgerald ©2018#######################

#Load requred libraries
library(gplots)
library(reshape)
library(ggplot2)
library(ggrepel)
library(grid)
library(gridExtra)
#library(dynamicTreeCut)
#library(mclust)
library(pvclust)
library(NbClust)
#library(ggdendro) #Dendrograms

my_hclust_fun = function(x) {hclust(x, method = "ward.D2")}

##################Import and process OrthoMCL data#################
#Set Working directory
setwd('~/Dropbox/Msc/ortho_mcl_annotation')

strain_labels = c("924/119", "A2-165", "942/18-1", "M21/2", "942/30-2", "942/32-1", "SL3/3", "922/41-1", "923/51-1", "923/61-1", "ATCC 27766",
                  "ATCC 27768", "942/8-14-2", "918/95b", "L2/6", "CYXN01", "CYYL01", "Indica", "CNCM_4540", "CNCM_4541", "CNCM_4542", 
                  "CNCM_4543", "CNCM_4544", "CNCM_4546", "CNCM_4573", "CNCM_4574", "CNCM_4575", "CNCM_4644", "AHMP_21", "HMI_19", "KLE1255") # Check manually if order is correct!
phylogroups = c("I", "II", "II", "I", "II", "II", "I", "II", "I", "II",
                "I", "I", "II", "I", "II", "I", "II", "II", "II",
                "II", "II", "II", "II", "I", "I", "II", "II", "I",
                "II", "II", "II") #Phylogroups as suggested in the literature
strain_origin = c("Present study","Previously published","Present study","Previously published","Present study","Present study",
                  "Previously published","Present study","Previously published", "Present study","Previously published",
                  "Previously published","Present study","Present study","Previously published","Previously published",
                  "Previously published","Previously published","Previously published","Previously published","Previously published",
                  "Previously published","Previously published","Previously published","Previously published","Previously published",
                  "Previously published","Previously published","Previously published","Previously published","Previously published")

#Read in parsed F. prausnitzii OrthoMCL ortholog tables
orthologs_counts.df = read.csv('fprau_groups.csv', header = TRUE, row.names = 1)
orthologs_names.df = read.csv('fprau_parsed_groups.csv', header = TRUE, row.names = 1, stringsAsFactors = FALSE)
row.names(orthologs_counts.df) = paste('fp_', row.names(orthologs_counts.df), sep = '') #Remove if not needed
row.names(orthologs_names.df) = paste('fp_', row.names(orthologs_names.df), sep = '') #Remove if not needed

#Compute core genome (genes present in at least (all-1) genomes to account for assembly errors)
core.genome.all = orthologs_counts.df[apply(orthologs_counts.df, 1, function(x) {length(which(x > 0)) > (length(x) - 1)}),]
core.genome.uniques = orthologs_counts.df[apply(orthologs_counts.df, 1, function(x) {all(x == 1)}),]

#Core proteome of F. prausnitzii (only clusters with a single member per genome - for use in multuple alignment)
faecalibacterium_core_prot = orthologs_names.df[rownames(core.genome.uniques),]
write.csv(faecalibacterium_core_prot, file = "faecalibacterium_core_prot.csv", quote=FALSE)

###############Estimation of pangenome and core genome size############################
#Orthologous groups accumulation curve (pan- and core genome size as a function of the number of added genomes)
orthologs.bin = orthologs_counts.df 
orthologs.bin[orthologs_counts.df > 0] = 1

core.matrix = matrix(,nrow=0, ncol=ncol(orthologs.bin))
pan.matrix = matrix(,nrow=0, ncol=ncol(orthologs.bin))
for(i in 1:100) {
  orthologs.bin.perm = orthologs.bin[,sample(ncol(orthologs.bin))]
  core.string=numeric(ncol(orthologs.bin.perm))
  pan.string=numeric(ncol(orthologs.bin.perm))
  core.string[1]=sum(orthologs.bin.perm[,1])
  pan.string[1]=core.string[1]
  for (j in 2:ncol(orthologs.bin.perm)) {
    core.string[j] = sum(apply(orthologs.bin.perm[,1:j], 1, sum)==j)
    pan.string[j] = sum(apply(orthologs.bin.perm[,1:j], 1, sum)>0)
  }
  core.matrix = rbind(core.matrix, core.string)
  pan.matrix = rbind(pan.matrix, pan.string)
}

pan_core_melted = rbind(melt(pan.matrix), melt(core.matrix))
pan_core_curves = ggplot(pan_core_melted, aes(x = as.factor(X2), y = value, colour = X1, fill = X1)) +
  theme_classic() + geom_boxplot(position = "identity") +
  xlab("No. of genomes included") + ylab("No. of orthologous groups") +
  ggtitle("Pan- and core- genome accumulation curves") +
  scale_fill_manual(values = c("darkgreen", "red")) +
  scale_colour_manual(values = c("darkgreen", "red")) +
  scale_y_continuous(breaks=seq(0,10000,500))

rm(core.string, pan.string, orthologs.bin.perm, core.matrix, pan.matrix, pan_core_melted)

#############PCA based on distribution of OrthoMCL orthologs################################
orthologs_pca = prcomp(t(orthologs_counts.df))
orthologs_ev = orthologs_pca$sdev^2/sum(orthologs_pca$sdev^2) #Compute relative eigenvalues
barplot(orthologs_ev[1:20], main = "Scree plot. Fraction of variance explained by first 20 PCA axes")

orthologs_pc_axes = data.frame(strain = strain_labels,
                               pc1 = orthologs_pca$x[,1],
                               pc2 = orthologs_pca$x[,2],
                               pc3 = orthologs_pca$x[,3],
                               phylogroup = phylogroups,
                               origin = strain_origin)

pcoa_orthologs = ggplot(orthologs_pc_axes, aes(x = pc1, y = pc2, label = strain, group = phylogroup,
                                               colour = phylogroup, fill = phylogroup, shape = origin)) +
  theme_classic() + geom_vline(xintercept = 0, linetype = 2, colour = "grey", size = 1.5) +
  geom_point(size = 3) + geom_text_repel(nudge_x = 2, nudge_y = 2, colour = "black") +
  stat_ellipse(geom = "polygon", alpha = 0.3) +
  xlab(paste("PC1, ", round(orthologs_ev[1]*100), "%")) +
  ylab(paste("PC2, ", round(orthologs_ev[2]*100), "%")) +
  ggtitle("") + theme(plot.title = element_text(hjust = 0.5, size = 15)) +
  scale_shape_manual(values=c(17,19))

rm(strain_labels, phylogroups, strain_origin)

###########Hierarchical clustering############################################
#Create distance matrix and perform hierarchical clustering
orthologs_counts.df2 = orthologs_counts.df
colnames(orthologs_counts.df2) = orthologs_pc_axes$strain
orthologs.dm = dist(t(orthologs_counts.df2))
orthologs_ward_clust = hclust(orthologs.dm, method = "ward.D2")
orthologs_pc_axes$clusters_k2 = cutree(orthologs_ward_clust, k = 2)
#orthologs_counts_pvclust = pvclust(orthologs_counts.df2, method.hclust="ward.D2", method.dist = "euclidean")

#Visulalisation using R base graphics
plot(orthologs_ward_clust,
     main = "Hierarchical clustering of genomes using Ward algorithm and Euclidean distances, k = 2", lwd = 2)
rect.hclust(orthologs_ward_clust, k = 2, border = c("#F8766D", "#00BFC4"))
par(lwd = 2, mar=c(5,5,5,5))

#Clustering statistics
#orthologs_counts_mclust = Mclust(t(orthologs_counts.df2))

#orthologs_counts_nbclust = NbClust(t(orthologs_counts.df2), distance = "euclidean", method = "ward.D2", index = "gap")
#plot(orthologs_counts_nbclust$All.CriticalValues)
#lines(orthologs_counts_nbclust$All.CriticalValues)
#print(orthologs_counts_nbclust$Best.partition)

#Visualisation using ggplot2
#orthologs_dendro = dendro_data(orthologs_ward_clust, type="rectangle")
#ggplot(segment(orthologs_dendro)) + geom_segment(aes(x=x, y=y, xend=xend, yend=yend))

#############Import and process COG annotations (done by BLASTp of consensus sequences)################
#Read in top blast hits against COG database
Unique_ID_tags.df = read.csv('fprau_final_ortho_mcl_blast_out_deduplicated.csv', header = FALSE)
colnames(Unique_ID_tags.df) = c("fp_group", "ID_tag")
Unique_ID_tags.df$fp_group = paste('fp_', Unique_ID_tags.df$fp_group, sep = '') #Remove if not needed

#Read in table of COG group codes
cog_value.df = read.csv('cog_codes.csv', header = FALSE)
colnames(cog_value.df) = c("ID_tag", "COG_number")
cog_value.df$COG_number = as.character(cog_value.df$COG_number)

#Read in COG functional subcategory ncodes
cog_to_function.df = read.csv('cog_to_function.csv')
colnames(cog_to_function.df) = c("COG", "subcategory", "name")
cog_to_function.df$COG = as.character(cog_to_function.df$COG)

#Parse all COG data into a single table
Unique_ID_tags.df$COG_number = NA
Unique_ID_tags.df$subcategory = NA
Unique_ID_tags.df$name = NA

for (i in rownames(Unique_ID_tags.df))
{
  Unique_ID_tags.df[i, "COG_number"] = cog_value.df[cog_value.df[,"ID_tag"] == Unique_ID_tags.df[i,"ID_tag"],"COG_number"][1]
  Unique_ID_tags.df[i, "subcategory"] = as.character(cog_to_function.df[cog_to_function.df$COG == Unique_ID_tags.df[i, "COG_number"],]$subcategory)
  Unique_ID_tags.df[i, "name"] = as.character(cog_to_function.df[cog_to_function.df$COG == Unique_ID_tags.df[i, "COG_number"],]$name)
  
  #output[i] = length(cog_value.df[cog_value.df[,"ID_tag"] == Unique_ID_tags.df[i,"ID_tag"],"COG_number"])
}
rm(cog_value.df, cog_to_function.df)

#COG annotations to F. prausnitzii pan-, core- and accessory genome (only the first COG hit is considered in each case)
fpr_pangenome_annotation.df = 
  data.frame(row.names = rownames(orthologs_counts.df), stringsAsFactors=FALSE)

for (i in rownames(fpr_pangenome_annotation.df))
{
  fpr_pangenome_annotation.df[i, "COG_number"] = Unique_ID_tags.df[Unique_ID_tags.df$fp_group == i,"COG_number"][1]
  fpr_pangenome_annotation.df[i, "subcategory"] = Unique_ID_tags.df[Unique_ID_tags.df$fp_group == i,"subcategory"][1]
  fpr_pangenome_annotation.df[i, "name"] = Unique_ID_tags.df[Unique_ID_tags.df$fp_group == i,"name"][1]
}

fpr_pangenome_annotation.df[is.na(fpr_pangenome_annotation.df)] = "0"
fpr_coregenome_annotation.df = fpr_pangenome_annotation.df[rownames(core.genome.all),]
fpr_accessgenome_annotation.df = fpr_pangenome_annotation.df[!(rownames(fpr_pangenome_annotation.df) %in% rownames(core.genome.all)),]

write.table(fpr_pangenome_annotation.df, "fpr_pangenome_COG_annotation.txt", row.names = TRUE, sep = "\t")
rm(Unique_ID_tags.df)

#Counts of subcategories per F. prausnitzii strain (only the first three categories are counted)
cog_subcategories = read.csv('function_to_name.csv', header = TRUE)
fpr_coregenome_cog_subcat = data.frame(row.names = levels(cog_subcategories$Subcategory))
fpr_coregenome_cog_subcat[,colnames(orthologs_counts.df)] = NA
fpr_accessgenome_cog_subcat = fpr_coregenome_cog_subcat

  #Core genomes
for (i in rownames(fpr_coregenome_cog_subcat))
{
  fp_codes_temp = rownames(fpr_coregenome_annotation.df[substring(fpr_coregenome_annotation.df$subcategory, 1, 1) == i | substring(fpr_coregenome_annotation.df$subcategory, 2, 2) == i | substring(fpr_coregenome_annotation.df$subcategory, 3, 3) == i,])
  fpr_coregenome_cog_subcat[i, ] = apply(orthologs_counts.df[fp_codes_temp,], 2, sum)
}
fpr_coregenome_cog_subcat = fpr_coregenome_cog_subcat[!(rownames(fpr_coregenome_cog_subcat) %in% c("A", "B", "Y", "Z")),] #Remove sparse or absent subcategories

  #Accessory genomes
for (i in rownames(fpr_accessgenome_cog_subcat))
{
  fp_codes_temp = rownames(fpr_accessgenome_annotation.df[substring(fpr_accessgenome_annotation.df$subcategory, 1, 1) == i | substring(fpr_accessgenome_annotation.df$subcategory, 2, 2) == i | substring(fpr_accessgenome_annotation.df$subcategory, 3, 3) == i,])
  fpr_accessgenome_cog_subcat[i, ] = apply(orthologs_counts.df[fp_codes_temp,], 2, sum)
}
fpr_accessgenome_cog_subcat = fpr_accessgenome_cog_subcat[!(rownames(fpr_accessgenome_cog_subcat) %in% c("A", "B", "Y", "Z")),] #Remove sparse or absent subcategories

#Wilcoxon test between core and accessory genome
core_access_COG_wilcox_p = numeric()
for (i in rownames(fpr_accessgenome_cog_subcat))
{
  core_access_COG_wilcox_p[i] = wilcox.test(as.numeric(fpr_coregenome_cog_subcat[i,]), as.numeric(fpr_accessgenome_cog_subcat[i,]))$p.value
}
core_access_COG_wilcox_p = p.adjust(core_access_COG_wilcox_p, method = "bonferroni")
significant_COG_categories =
  names(core_access_COG_wilcox_p[core_access_COG_wilcox_p < 0.05 & !is.na(core_access_COG_wilcox_p)])

#COG subcategories with significant diference in representation between core and accessory genome
print(significant_COG_categories)

#Pangenome composition (piechart)
fpr_pangenome_cog_stat = melt(table(fpr_pangenome_annotation.df$subcategory))
fpr_pangenome_cog_sum = sum(fpr_pangenome_cog_stat$value)
fpr_pangenome_cog_stat = fpr_pangenome_cog_stat[fpr_pangenome_cog_stat$value > 100,]
fpr_pangenome_cog_stat$Var.1 = as.character(fpr_pangenome_cog_stat$Var.1)
fpr_pangenome_cog_stat = rbind(fpr_pangenome_cog_stat, c("other", fpr_pangenome_cog_sum - sum(fpr_pangenome_cog_stat$value)))
fpr_pangenome_cog_stat$value = as.integer(fpr_pangenome_cog_stat$value)
fpr_pangenome_cog_stat$Var.2 = 
  c(unlist(sapply(fpr_pangenome_cog_stat$Var.1, function(x) as.character(cog_subcategories[cog_subcategories$Subcategory == as.character(x), c("Name")]))), "Other")
fpr_pangenome_cog_stat[1,1] = "Not_in_COG"
fpr_pangenome_cog_stat = fpr_pangenome_cog_stat[order(fpr_pangenome_cog_stat$value, decreasing = TRUE),]
fpr_pangenome_cog_stat$Var.3 = as.character(c("white", "white", "#b15928", "#a6cee3", "#1f78b4", "lightgrey", "#b2df8a",
                                              "#33a02c", "#fb9a99", "#e31a1c", "darkgrey", "#fdbf6f", "#6a3d9a", "black", "magenta", "#ffff99",
                                              "yellow"))
colnames(fpr_pangenome_cog_stat) = c("category", "count", "name", "colour")
rownames(fpr_pangenome_cog_stat) = fpr_pangenome_cog_stat$category
fpr_pangenome_cog_stat$name = factor(fpr_pangenome_cog_stat$name, levels = fpr_pangenome_cog_stat$name)
  
cog_pie = ggplot(fpr_pangenome_cog_stat[-1,], aes(x = factor(1), y = count, fill = name, label = count)) + theme_classic() +  
  geom_bar(stat = "identity", show.legend = TRUE, colour = "black") + coord_polar(theta = "y") +
  geom_text(position = position_stack(vjust = 0.5), aes(x = 1.6)) +
  ylab("") + xlab("No. of orthologous groups") + 
  theme(legend.text = element_text(size = 8), legend.key.size = unit(0.5, "cm"), legend.title=element_blank(), axis.text=element_blank()) +
  scale_fill_manual(values = fpr_pangenome_cog_stat$colour[-1]) +
  ggtitle("Composition of COG categories in the pangenome of F. prausnitzii")

rm(fpr_pangenome_cog_sum)

#Stripchart of COG categories with unequal ditribution between core- and accesory genome (p < 0.05 in Wilcoxon test)
fpr_cog_stat = rbind(melt(as.matrix(fpr_coregenome_cog_subcat[significant_COG_categories,])),
                     melt(as.matrix(fpr_accessgenome_cog_subcat[significant_COG_categories,])))
fpr_cog_stat[c(1:(nrow(fpr_cog_stat)/2)),"group"] = "Core"
fpr_cog_stat[is.na(fpr_cog_stat$group), "group"] = "Accessory"
fpr_cog_stat$group = as.factor(fpr_cog_stat$group)
fpr_cog_stat$X1 = 
  sapply(as.character(fpr_cog_stat$X1), function(x) {cog_subcategories[cog_subcategories$Subcategory == x, "Name"]})
fpr_cog_stat$X1 = factor(
  fpr_cog_stat$X1,
  levels = levels(fpr_cog_stat$X1)[c(1,13,14,27,2,3,22,6,8,11,20,21,17,15,4,16,26,25,10,18,24,5,7,9,23,19,12)] #Manual sorting!
)

cog_stripchart =
  ggplot(fpr_cog_stat[fpr_cog_stat$X1 != 0,], aes(x = X1, y = value, colour = group)) + geom_jitter(alpha = 0.3) +
  stat_summary(fun.y = median, fun.ymin = median, fun.ymax = median, geom = "crossbar", width = 1) +
  theme_classic() + theme(plot.margin = margin(10, 10, 10, 50)) + 
  xlab("") + ylab("No. of orthologous groups per genome") + 
  ggtitle("Different COG categories show uneven distribution\nbetween core- and accessory genome in F. prausnitzii (p < 0.05)") +
  theme(plot.title = element_text(hjust = 0.5, size = 15), axis.text.x = element_text(angle = 45, hjust = 1)) +
  scale_color_manual(values = c("blue", "red")) + xlab("")

rm(fpr_cog_stat)

###################Functional differences between the two genomogroups##########################
#Wilcoxon test of COGs between identified phylogoups
phylogroups_wilcox_p = numeric()
for (i in rownames(orthologs_counts.df))
{
  phylogroups_wilcox_p[i] = wilcox.test(as.numeric(orthologs_counts.df[i,rownames(orthologs_pc_axes[orthologs_pc_axes$clusters_k2 == 1,])]),
                                            as.numeric(orthologs_counts.df[i,rownames(orthologs_pc_axes[orthologs_pc_axes$clusters_k2 == 2,])]))$p.value
}
phylogroups_wilcox_p = p.adjust(phylogroups_wilcox_p, method = "fdr")
significant_orthologs_phylogroups.ids = names(phylogroups_wilcox_p[phylogroups_wilcox_p < 0.05 & !is.na(phylogroups_wilcox_p)])

#Orthologous groups with significant diference in representation between the two phylogoups
print(significant_orthologs_phylogroups.ids) #Prints orthologs with differential abundance in the two phylogoups
significant_orthologs_phylogroups = fpr_pangenome_annotation.df[significant_orthologs_phylogroups.ids,]
significant_orthologs_annotated = significant_orthologs_phylogroups[significant_orthologs_phylogroups$name != 0,]

significant_orthologs_annotated.mtx = as.matrix(orthologs_counts.df[rownames(significant_orthologs_annotated),])
significant_orthologs_all.mtx = as.matrix(orthologs_counts.df[rownames(significant_orthologs_phylogroups),])

rm(significant_orthologs_phylogroups.ids)

#Add phylogroup choice for each orthogroup
significant_orthologs_phylogroups$preferred_phylogroup = NA
for (i in rownames(significant_orthologs_phylogroups)) {
  if (sum(significant_orthologs_all.mtx[i, rownames(orthologs_pc_axes[orthologs_pc_axes$clusters_k2 == 1,])]) >
      sum(significant_orthologs_all.mtx[i, rownames(orthologs_pc_axes[orthologs_pc_axes$clusters_k2 == 2,])])) {
    significant_orthologs_phylogroups[i, "preferred_phylogroup"] = 1
  }
  else {significant_orthologs_phylogroups[i, "preferred_phylogroup"] = 2}
}
write.table(significant_orthologs_phylogroups, "significant_orthologs_phylogroups.txt", row.names = TRUE, sep = "\t")

#Create list of genomogroup_specific proteins in 918/95b and 942/30-2
groupspecific_proteins_95b = orthologs_names.df[rownames(significant_orthologs_phylogroups),"fp95b"]
groupspecific_proteins_95b = groupspecific_proteins_95b[groupspecific_proteins_95b != ""]
groupspecific_proteins_30 = orthologs_names.df[rownames(significant_orthologs_phylogroups),"fp30"]
groupspecific_proteins_30 = groupspecific_proteins_30[groupspecific_proteins_30 != ""]

write.table(groupspecific_proteins_95b, "groupspecific_proteins_95b.txt", col.names = FALSE, row.names = FALSE, quote = FALSE)
write.table(groupspecific_proteins_30, "groupspecific_proteins_30.txt", col.names = FALSE, row.names = FALSE, quote = FALSE)

#Core- and accessory genome size statistics (barplot)
fpr_core_access_stat = rbind(apply(core.genome.all, 2, sum),
      apply(orthologs_counts.df[!(rownames(orthologs_counts.df) %in% rownames(core.genome.all)),], 2, sum))
rownames(fpr_core_access_stat) = c("Core", "Accessory")

#strain_order = heatmap.2(as.matrix(orthologs.bin), scale = "none")$colInd
fpr_core_access_stat_melt = melt(fpr_core_access_stat)
fpr_core_access_stat_melt$X2 = factor(fpr_core_access_stat_melt$X2,
  levels = colnames(fpr_core_access_stat)[orthologs_ward_clust$order])

genome_barchart = ggplot(fpr_core_access_stat_melt, aes(x = X2, fill = X1, y = value)) +
  theme_classic() + geom_bar(stat="identity") +
  theme(axis.text.x = element_text(angle = 30, hjust = 1), plot.title = element_text(hjust = 0.5, size = 15)) +
  ggtitle("Relative size of core- and accessory genome in F. prausnitzii strains") +
  scale_x_discrete(labels = orthologs_pc_axes$strain[orthologs_ward_clust$order]) +
  scale_fill_manual(values = c("blue", "red")) + xlab("") + ylab("No. of orthologs")

#Annotations for F. prausnitzii heatmap plot with colors
fpr_pangenome_annotation.df$colour = substring(fpr_pangenome_annotation.df$subcategory, 1, 1)
fpr_pangenome_annotation.df$colour[fpr_pangenome_annotation.df$colour != 0] = "black"
fpr_pangenome_annotation.df$colour[fpr_pangenome_annotation.df$colour == 0] = "white"

####################Draw PDF images###################################
pdf(file="fpr_orthomcl_fig1.pdf", paper="A4r", width=11, height=8.5)
par(lend = 1, lwd = 2, mar=c(10,10,10,10))
plot(orthologs_ward_clust,
     main = "Hierarchical clustering of genomes using Ward algorithm and Euclidean distances, k = 2", lwd = 2)
rect.hclust(orthologs_ward_clust, k = 2, border = c("#F8766D", "#00BFC4"))
dev.off()

pdf(file="fpr_orthomcl_fig2.pdf", paper="A4r", width=11, height=8.5)
heatmap.2(as.matrix(orthologs.bin), scale = "none", col = c("yellow", "blue"), dendrogram = "column",
          labRow = NA, labCol = orthologs_pc_axes$strain, hclustfun = my_hclust_fun,
          trace = "none", key = FALSE, margins = c(10, 10),
          RowSideColors = fpr_pangenome_annotation.df$colour,
          ColSideColors = c("#F8766D", "#00BFC4")[orthologs_pc_axes$clusters_k2],
          main = "De novo orthologous protein groups\nin F. prausnitzii strains")
par(lend = 1)
legend("left",  legend = c("COG-annotated", "Not in COG"), col = c("black", "white"), lty = 1, lwd = 5, cex = 0.6)
dev.off()

pdf(file="fpr_orthomcl_fig3.pdf", paper="A4", width=8.5, height=11)
grid.arrange(pcoa_orthologs, cog_stripchart, nrow = 2)
dev.off()

pdf(file="fpr_orthomcl_fig4.pdf", paper="A4", width=8.5, height=11)
grid.arrange(pan_core_curves, genome_barchart, cog_pie, nrow = 3)
dev.off()

pdf(file="fpr_orthomcl_fig5.pdf", paper="A4", width=8.5, height=11)
heatmap.2(significant_orthologs_annotated.mtx,
          scale = "none", trace = "none",
          col = c("white", "orange", "red", "magenta", "cyan", "blue"),
          labCol = orthologs_pc_axes$strain,
          labRow = gsub("0", "", significant_orthologs_annotated$name),
          cexRow = 0.3,
          margins = c(5,20),
          hclustfun = my_hclust_fun,
          keysize = 1,
          main = "",
          RowSideColors = fpr_pangenome_cog_stat[substr(significant_orthologs_annotated$subcategory, 1, 1), "colour"],
          ColSideColors = c("#F8766D", "#00BFC4")[orthologs_pc_axes$clusters_k2])
par(lend = 1)
legend(0.6,1, legend = fpr_pangenome_cog_stat$name, col = fpr_pangenome_cog_stat$colour, lty = 1, lwd = 5, cex = 0.4, bg = "white")
text(c(0.32, 0.56), c(0.84, 0.84), labels = c("Genomogroup II","Genomogroup I"), cex = 0.8)
dev.off()

pdf(file="fpr_orthomcl_fig6.pdf", paper="A4", width=8.5, height=11)
heatmap.2(significant_orthologs_all.mtx,
          scale = "none", trace = "none",
          col = c("white", "orange", "red", "magenta", "cyan", "blue"),
          labCol = orthologs_pc_axes$strain,
          labRow = gsub("0", "", significant_orthologs_phylogroups$name),
          cexRow = 0.3,
          margins = c(5,20),
          hclustfun = my_hclust_fun,
          keysize = 1,
          main = "",
          RowSideColors = fpr_pangenome_cog_stat[substr(significant_orthologs_phylogroups$subcategory, 1, 1), "colour"],
          ColSideColors = c("#F8766D", "#00BFC4")[orthologs_pc_axes$clusters_k2])
par(lend = 1)
legend(0.6,1, legend = fpr_pangenome_cog_stat$name, col = fpr_pangenome_cog_stat$colour, lty = 1, lwd = 5, cex = 0.4, bg = "white")
text(c(0.32, 0.56), c(0.84, 0.84), labels = c("Genomogroup II","Genomogroup I"), cex = 0.8)
dev.off()

#rm(significant_orthologs_annotated.mtx, significant_orthologs_annotated)
save.image()
